/***************************************
	Auteur : Pierre Aubert
	Mail : pierre.aubert@lapp.in2p3.fr
	Licence : CeCILL-C
****************************************/

#ifndef __PEMPTY_BACKEND_H__
#define __PEMPTY_BACKEND_H__

#include "PSocketFlag.h"
#include "phoenix_mock_socket.h"

///@brief Set of parameters to be passed to create a socket with mock backend
struct PEmptyParam{
	///Host address
	std::string address;
	///Connection port
	size_t port;
};

///@brief Backend to use Mock library with PAbtractSocket
class PEmptyBackend{
	public:
		///Define the socket of the backend used by the PAbstractSocketManager
		typedef int Socket;
		///Define the type of message used by the PAbstractSocketManager
		typedef DataStreamMsg Message;
		///Define the type of extra parameters which can be used to create a Socket used by the PAbstractSocketManager
		typedef PEmptyParam Param;
		
		PEmptyBackend();
		
		static Param client(const std::string & address, size_t port);
		static Param server(const std::string & address, size_t port);
		
		static bool createClientSocket(Socket & socket, const std::string & address, size_t port, const PEmptyParam & param);
		static bool createServerSocket(Socket & socket, const std::string & address, size_t port, const PEmptyParam & param);
		
		static bool createClientSocket(Socket & socket, const PEmptyParam & param);
		static bool createServerSocket(Socket & socket, const PEmptyParam & param);
		
		static bool send(Socket & socket, const Message& msg, PSendFlag::PSendFlag flag);
		
		static bool recv(Socket & socket, Message& msg, PRecvFlag::PRecvFlag flag);
		
		static void msgResize(Message& msg, size_t sizeMsg);
		static size_t msgSize(const Message& msg);
		static const DataStreamIter msgData(const Message& msg);
		static DataStreamIter msgData(Message& msg);
		
		static void close(Socket & socket);
		static bool isConnected(const Socket & socket);
};



#endif

