/***************************************
	Auteur : Pierre Aubert
	Mail : pierre.aubert@lapp.in2p3.fr
	Licence : CeCILL-C
****************************************/

#ifndef __PGENERIC_SOCKET_MANAGER_H__
#define __PGENERIC_SOCKET_MANAGER_H__

#include <map>
#include "PGenericSocket.h"
#include "PEmptyBackend.h"
#include "PMockBackend.h"

///@brief Socket manager for PGenericSocket
template<typename _TSocketKey, typename _TBackend, typename _TMockBackend>
class PGenericSocketManager{
	public:
		typedef _TBackend Backend;
		typedef _TMockBackend Mock;
		PGenericSocketManager(PSocketMode::PSocketMode mode = PSocketMode::NO_MOCK);
		virtual ~PGenericSocketManager();
		
		void setMode(PSocketMode::PSocketMode mode);
		PSocketMode::PSocketMode getMode() const;
		bool addClientSocket(const _TSocketKey & name, const typename _TBackend::Param & param, const typename _TMockBackend::Param & mockParam);
		bool addServerSocket(const _TSocketKey & name, const typename _TBackend::Param & param, const typename _TMockBackend::Param & mockParam);
		
		void removeSocket(const _TSocketKey & name);
		void clear();
		
		///Send data on the given socket
		/**	@param name : name of the socket to be used
		* 	@param data : data to be sent
		* 	@param flag : flag to be used to send the message (BLOCK, NON_BLOCK, etc)
		* 	@return true on success, false otherwise
		*/
		template<typename U>
		bool sendData(const _TSocketKey & name, const U & data, PSendFlag::PSendFlag flag = PSendFlag::BLOCK){
			PGenericSocket<_TBackend, _TMockBackend> * socket = getSocket(name);
			if(socket != NULL){
				return socket->sendData(data, flag);
			}else{
				return false;
			}
		}
		
		bool sendMsg(const _TSocketKey & name, typename _TBackend::Message & msg, PSendFlag::PSendFlag flag = PSendFlag::BLOCK);
		
		///Recieve data from the given socket
		/**	@param name : name of the socket to be used
		* 	@param data : data to be recieved
		* 	@param flag : flags to be used to send the message (BLOCK, NON_BLOCK, etc)
		* 	@return true on success, false otherwise
		*/
		template<typename U>
		bool recvData(const _TSocketKey & name, U & data, PRecvFlag::PRecvFlag flag = PRecvFlag::BLOCK){
			PGenericSocket<_TBackend, _TMockBackend> * socket = getSocket(name);
			if(socket != NULL){
				return socket->recvData(data, flag);
			}else{
				return false;
			}
		}
		
		bool recvMsg(const _TSocketKey & name, typename _TBackend::Message & msg, PRecvFlag::PRecvFlag flag = PRecvFlag::BLOCK);
		
		PGenericSocket<_TBackend, _TMockBackend>* getSocket(const _TSocketKey & name);
		bool isSocketExist(const _TSocketKey & name) const;
		bool isConnected(const _TSocketKey & name) const;
		
	private:
		void initialisationPGenericSocketManager(PSocketMode::PSocketMode mode);
		
		///Mode of the Socket (no mock, mock, mock_record)
		PSocketMode::PSocketMode p_mode;
		
		///Map of the zmq sockets to be used by the manager
		std::map<_TSocketKey, PGenericSocket<_TBackend, _TMockBackend> *> p_mapSocket;
		
};

#include "PGenericSocketManager_impl.h"


#endif

