/***************************************
	Auteur : Pierre Aubert
	Mail : pierre.aubert@lapp.in2p3.fr
	Licence : CeCILL-C
****************************************/

#ifndef __PMOCKBACKEND_H__
#define __PMOCKBACKEND_H__

#include "PSocketFlag.h"
#include "phoenix_mock_socket.h"

///@brief Set of parameters to be passed to create a socket with mock backend
struct PMockParam{
	///Host address
	std::string address;
	///Connection port
	size_t port;
	///True to record the activity of the backend durring real use to make reusable mock
	bool isMockRecord;
	///Directory where to find/save mock files
	std::string mockDirectory;
};

///@brief Data to be used to handle the mock socket
struct PMockSocket{
	///Parameters of the mock
	PMockParam param;
	///Name of the file to read messages
	std::string fileNameMessage;
	///Vector of messages
	PVecMockMessage vecMessage;
	///Index of the current message
	size_t eventIndex;
};

///@brief Backend to use Mock library with PAbtractSocket
class PMockBackend{
	public:
		///Define the socket of the backend used by the PAbstractSocketManager
		typedef PMockSocket Socket;
		///Define the type of message used by the PAbstractSocketManager
		typedef DataStreamMsg Message;
		///Define the type of extra parameters which can be used to create a Socket used by the PAbstractSocketManager
		typedef PMockParam Param;
		
		PMockBackend();
		
		static Param client(const std::string & address, size_t port, bool isMockRecord, const std::string & mockDirectory);
		static Param server(const std::string & address, size_t port, bool isMockRecord, const std::string & mockDirectory);
		
		static bool createClientSocket(Socket & socket, const PMockParam & param);
		static bool createServerSocket(Socket & socket, const PMockParam & param);
		
		static bool send(Socket & socket, const Message& msg, PSendFlag::PSendFlag flag);
		static bool recv(Socket & socket, Message& msg, PRecvFlag::PRecvFlag flag);
		
		static void msgResize(Message& msg, size_t sizeMsg);
		static size_t msgSize(const Message& msg);
		static const DataStreamIter msgData(const Message& msg);
		static DataStreamIter msgData(Message& msg);
		
		static void close(Socket & socket);
		static bool isConnected(const Socket & socket);
};


#endif

